@@ -1,5 +1,5 @@
 /****************************************************************************
-** $Id: application.cpp,v 1.7 2004/02/22 22:01:00 bherger Exp $
+** $Id: application.cpp,v 1.18 2004/06/08 20:39:32 bherger Exp $
 **
 ** Copyright (C) 1992-2000 Trolltech AS.  All rights reserved.
 **
@@ -98,6 +98,7 @@ using std::endl;
 #include "superscript.xpm"
 #include "subscript.xpm"
 #include "justifytools.h"
+#include "magnifytools.h"
 
 // left side toolbar
 #include "selecttool.xpm"
@@ -157,7 +158,9 @@ ApplicationWindow::ApplicationWindow()
   QString editCutText=tr("Click this button to cut a selection.<br><br>You can also select the Cut command from the Edit menu, or press Ctrl+X.");
   QString editCopyText=tr("Click this button to copy a selection.<br><br>You can also select the Copy command from the Edit menu, or press Ctrl+C.");
   QString editPasteText=tr("Click this button to paste a selection.<br><br>You can also select the Paste command from the Edit menu, or press Ctrl+V.");
-  
+  QString editMPText=tr("Click this button to zoom in.");
+  QString editMMText=tr("Click this button to zoom out.");
+
   // What's This? text for left side toolbar
   QString selectToolText = tr("Select tool<br><br>Use the Select tool to select and move items inside a box.<br><br>You can select multiple items and cut, copy, move and rotate them.");
   QString lassoToolText = tr("Lasso tool<br><br>Use the Lasso tool to select and move items by drawing a loop around them.<br><br>You can select multiple items and cut, copy, move and rotate them.");
@@ -183,7 +186,7 @@ ApplicationWindow::ApplicationWindow()
   QPixmap swatchblack, swatchred, swatchgreen, swatchblue;
   QPixmap selectIcon, drawBoxIcon, drawLineIcon, downLineIcon, upLineIcon,
     textIcon, arrowIcon, bracketIcon, cutIcon, copyIcon, pasteIcon, ringIcon,
-    dashIcon, symbolIcon, curveArrowIcon, chainIcon, lassoIcon;
+    dashIcon, symbolIcon, curveArrowIcon, chainIcon, lassoIcon, mmIcon, mpIcon;
 
   cw = new QWidget(this);
 
@@ -252,6 +255,20 @@ ApplicationWindow::ApplicationWindow()
 		       this, SLOT(Paste()), fileTools, "paste" );
   QWhatsThis::add(editPaste, editPasteText);
 
+  mpIcon = QPixmap(magnify_plus_xpm);
+  myfactory->setPixmap("mpicon", mpIcon );
+  QToolButton * editMP
+    = new QToolButton( mpIcon, tr("Zoom In"), QString::null,
+		       this, SLOT(MagnifyPlus()), fileTools, "plus" );
+  QWhatsThis::add(editMP, editMPText);
+
+  mmIcon = QPixmap(magnify_minus_xpm);
+  myfactory->setPixmap("mmicon", mmIcon );
+  QToolButton * editMM
+    = new QToolButton( mmIcon, tr("Zoom Out"), QString::null,
+		       this, SLOT(MagnifyMinus()), fileTools, "minus" );
+  QWhatsThis::add(editMM, editMMText);
+
   QPixmap *tmp_pm = new QPixmap(32, 20);
   tmp_pm->fill(QColor(210,210,210));
   QPainter pixpaint(tmp_pm);
@@ -383,7 +400,7 @@ ApplicationWindow::ApplicationWindow()
 
   // left side toolbar
   drawTools = new QToolBar(this, "draw operations");
-  moveToolBar(drawTools, QMainWindow::Left);
+  moveDockWindow(drawTools, Qt::DockLeft);
   selectIcon = QPixmap( selecttool );
   myfactory->setPixmap("selecttoolicon", selectIcon );
   QToolButton * selectObjects
@@ -513,7 +530,7 @@ ApplicationWindow::ApplicationWindow()
   // second (left? right?) toolbar - predefined rings
   ringTools = new QToolBar( this, "canned structures" );
   ringTools->setLabel( tr( "Canned Structures" ) );
-  moveToolBar(ringTools, QMainWindow::Left);
+  moveDockWindow(ringTools, Qt::DockLeft);
 
   XDC_ToolButton *b1;
   QBitmap mask1(24, 24);
@@ -635,6 +652,23 @@ ApplicationWindow::ApplicationWindow()
   id = flipSub->insertItem( tr("Flip &horizontal"), this, SLOT(FlipH()) );
   id = flipSub->insertItem( tr("Flip &vertical"), this, SLOT(FlipV()) );
 
+  QPopupMenu * zoomSub = new QPopupMenu(this);
+  id = zoomSub->insertItem(tr("Normal (100%)"),this,SLOT(Magnify100()),
+			   CTRL+Key_5);
+  id=zoomSub->insertItem(tr("Zoom out"),this,SLOT(MagnifyMinus()),CTRL+Key_1);
+  id = zoomSub->insertItem(tr("Zoom in"),this,SLOT(MagnifyPlus()),CTRL+Key_0);
+  /*
+  zoomSub->insertSeparator();
+  id = zoomSub->insertItem(tr("25%"),this,SLOT(Dummy()),CTRL+Key_2);
+  id = zoomSub->insertItem(tr("50%"),this,SLOT(Dummy()),CTRL+Key_3);
+  id = zoomSub->insertItem(tr("75%"),this,SLOT(Dummy()),CTRL+Key_4);
+  id = zoomSub->insertItem(tr("100%"),this,SLOT(Dummy()) );
+  id = zoomSub->insertItem(tr("125%"),this,SLOT(Dummy()),CTRL+Key_6);
+  id = zoomSub->insertItem(tr("150%"),this,SLOT(Dummy()),CTRL+Key_7);
+  id = zoomSub->insertItem(tr("175%"),this,SLOT(Dummy()),CTRL+Key_8);
+  id = zoomSub->insertItem(tr("200%"),this,SLOT(Dummy()),CTRL+Key_9);
+  */
+
   QPopupMenu * edit = new QPopupMenu(this);
   menuBar()->insertItem(tr("&Edit"), edit);
 
@@ -650,6 +684,8 @@ ApplicationWindow::ApplicationWindow()
 		   CTRL+SHIFT+Key_A);
   edit->insertItem(tr("&Rotate"), rotateSub );
   edit->insertItem(tr("&Flip"), flipSub );
+  edit->insertSeparator();
+  edit->insertItem(tr("&Zoom"), zoomSub );
 
   QPopupMenu * groupmenu = new QPopupMenu(this);
   menuBar()->insertItem(tr("&Group"), groupmenu);
@@ -688,16 +724,16 @@ ApplicationWindow::ApplicationWindow()
   //		     SLOT(reactionAnalysisTest()) );
   reactionTools->insertItem( tr("Estimate gas-phase enthalphy change"),
 			     this, SLOT(reactionAnalysisEnthalpy()) );
+  reactionTools->insertItem( tr("Estimate partial charges"),
+			     this, SLOT(CalcPartialCharge()) );
   reactionTools->insertItem( tr("Compare 1H NMR"),
 			     this, SLOT(reactionAnalysis1HNMR()) );
   reactionTools->insertItem( tr("Compare 13C NMR"),
 			     this, SLOT(reactionAnalysis13CNMR()) );
 
-  /*
   reactionTools->insertItem( tr("Retrosynthesis"), this, SLOT(Retro()) );
   reactionTools->insertItem( tr("Get bond identifier"), this, 
 			     SLOT(RetroBondName()) );
-  */
 
   QPopupMenu * tools = new QPopupMenu(this);
   menuBar()->insertItem(tr("T&ools"), tools);
@@ -707,10 +743,21 @@ ApplicationWindow::ApplicationWindow()
 		    SLOT(saveCustomRing()) );
   tools->insertSeparator();
   tools->insertItem(tr("Molecule information..."),this,SLOT(MoleculeInfo()) );
-  tools->insertItem(tr("Calculate empirical formula"), this, SLOT(CalcEF()) );
-  tools->insertItem(tr("Calculate molecular weight"), this, SLOT(CalcMW()) );
+  //tools->insertItem(tr("Calculate empirical formula"),this, SLOT(CalcEF()) );
+  //tools->insertItem(tr("Calculate molecular weight"), this, SLOT(CalcMW()) );
   tools->insertItem(tr("Elemental analysis"), this, SLOT(CalcEA()) );
-  //tools->insertItem("IUPAC name", this, SLOT(CalcName()) );
+
+  /*
+  FILE *pinfile = popen("python -c \"from frowns import Smiles;mol = Smiles.smilin(\\\"c1ccccc1\\\");print mol.cansmiles()\"", "r");
+  if (pinfile) {
+    char csmiles[256];
+    fgets(csmiles, 250, pinfile);
+    if (strncmp(csmiles, "c1ccccc1", 8) == 0)
+      tools->insertItem("Molecule name", this, SLOT(CalcName()) );
+    pclose(pinfile);
+  }
+  */
+
   tools->insertItem("Predict 1H NMR", this, SLOT(Calc1HNMR()) );
   tools->insertItem(tr("Predict 13C NMR"), this, SLOT(Calc13CNMR()) );
   tools->insertItem(tr("Predict IR"), this, SLOT(CalcIR()) );
@@ -888,6 +935,13 @@ QPopupMenu *ApplicationWindow::BuildBracketMenu() {
   p1 = QPixmap(ellipsebracket_xpm);
   bracketlist.append(QString("ELLIPSE"));
   bracketSub->insertItem( p1, this, SLOT(FromBracketMenu(int)), 0, 4);
+
+  p1 = QPixmap(closedsquarebracket_xpm);
+  bracketlist.append(QString("CLOSEDSQUARE"));
+  bracketSub->insertItem( p1, this, SLOT(FromBracketMenu(int)), 0, 5);
+  p1 = QPixmap(circlebracket_xpm);
+  bracketlist.append(QString("CIRCLE"));
+  bracketSub->insertItem( p1, this, SLOT(FromBracketMenu(int)), 0, 6);
   return bracketSub;
 }
 
@@ -1113,7 +1167,7 @@ void ApplicationWindow::save()
   OBNewSave();
 
   return;
-
+  
   if ( filename.isEmpty() ) {
     saveAs();
     return;
@@ -1246,6 +1300,10 @@ void ApplicationWindow::SavePNG() {
   exit(0);  // this function is only used in non-interactive mode
 }
 
+void ApplicationWindow::Save3D() {
+  exit(0);  // this function is only used in non-interactive mode
+}
+
 void ApplicationWindow::print()
 {
   r->Print();
@@ -1368,6 +1426,7 @@ void ApplicationWindow::MakeNetDialog() {
     QMessageBox::warning( this, tr("Database query failed"), tr("No molecules in the database match the query.") );
     return;
   }
+  /*
   if (choices.count() == 1) {
     int i1 = choices[0].find("|");
     QString subfile = choices[0].left(i1) + ".mol";
@@ -1378,14 +1437,16 @@ void ApplicationWindow::MakeNetDialog() {
     r->Inserted();
     return;
   }
+  */
   NetChooseDialog nc(this, "net choose dialog", choices);
   if ( !nc.exec() ) return;
   cout << nc.getFile() << endl;
-  QString wf = na.getFile(n.getServer(), nc.getFile());
-  if (wf.contains("file not found") > 0) {
-    QMessageBox::warning( this, tr("Database query failed"), tr("An error occured.  The server cannot find the selected molecule.") );
-    return;
-  }
+  // TODO: insert SMILES string returned by database
+  c->fromSMILES(nc.getFile());
+  r->Inserted();
+  r->repaint(false);
+
+  /*
   if (nc.getFile().contains(".mol")) {
     c->DeselectAll();
     c->SetTopLeft(sv->viewportToContents(QPoint(0,0)));
@@ -1393,6 +1454,7 @@ void ApplicationWindow::MakeNetDialog() {
     r->Inserted();
     return;
   }
+  */
 }
 
 void ApplicationWindow::PageSetup() {
@@ -1461,7 +1523,7 @@ void ApplicationWindow::HelpTopic(QString topic) {
 
 // new manual (based on QTextBrowser) -- derived from Qt example "helpviewer"
 /****************************************************************************
-** $Id: application.cpp,v 1.7 2004/02/22 22:01:00 bherger Exp $
+** $Id: application.cpp,v 1.18 2004/06/08 20:39:32 bherger Exp $
 **
 ** Copyright (C) 1992-2000 Trolltech AS.  All rights reserved.
 **
@@ -1501,6 +1563,9 @@ void ApplicationWindow::Calc13CNMR() { r->Tool(MODE_TOOL_13CNMR); }
 void ApplicationWindow::Calc1HNMR() { r->Tool(MODE_TOOL_1HNMR); }
 void ApplicationWindow::CalcIR() { r->Tool(MODE_TOOL_IR); }
 void ApplicationWindow::CalcpKa() { r->Tool(MODE_TOOL_PKA); }
+void ApplicationWindow::CalcPartialCharge() { 
+  //r->Tool(MODE_TOOL_PARTIAL_CHARGE); 
+}
 void ApplicationWindow::CalcKOW() { r->Tool(MODE_TOOL_KOW); }
 void ApplicationWindow::CalcName() { r->Tool(MODE_TOOL_NAME); }
 void ApplicationWindow::ToSMILES() { r->Tool(MODE_TOOL_TOSMILES); }
@@ -1573,3 +1638,33 @@ void ApplicationWindow::showDYK() {
   DYKDialog dyk1;
   dyk1.exec();
 }
+void ApplicationWindow::MagnifyPlus() {
+  preferences.setZoom( preferences.getZoom() + 25 );
+  if (preferences.getZoom() > 200) preferences.setZoom(200);
+  r->zoomEvent();
+  hruler->zoomEvent();
+  vruler->zoomEvent();
+  SetStatusBar( tr("Zoom = %1 %").arg(preferences.getZoom()) );
+}
+void ApplicationWindow::MagnifyMinus() {
+  preferences.setZoom( preferences.getZoom() - 25 );
+  if (preferences.getZoom() < 25) preferences.setZoom(25);
+  r->zoomEvent();
+  hruler->zoomEvent();
+  vruler->zoomEvent();
+  SetStatusBar( tr("Zoom = %1 %").arg(preferences.getZoom()) );
+}
+void ApplicationWindow::Magnify100() {
+  preferences.setZoom( 100 );
+  r->zoomEvent();
+  hruler->zoomEvent();
+  vruler->zoomEvent();
+  SetStatusBar( tr("Zoom = %1 %").arg(preferences.getZoom()) );
+}
+void ApplicationWindow::Zoom(int z1) {
+
+  r->zoomEvent();
+  hruler->zoomEvent();
+  vruler->zoomEvent();
+  SetStatusBar( tr("Zoom = %1 %").arg(preferences.getZoom()) );
+}
