@@ -1,5 +1,5 @@
 /****************************************************************************
-** $Id: application.h,v 1.2 2004/02/19 22:34:55 bherger Exp $
+** $Id: application.h,v 1.7 2004/06/08 01:22:45 bherger Exp $
 **
 ** Copyright (C) 1992-2000 Trolltech AS.  All rights reserved.
 **
@@ -47,6 +47,7 @@ public slots:
     void saveAs();
     void savePicture();
     void SavePNG();
+    void Save3D();
     void PageSetup();
     void print();
     void MakeRingDialog();
@@ -92,6 +93,7 @@ public slots:
     void Calc1HNMR();
     void CalcIR();
     void CalcpKa();
+    void CalcPartialCharge();
     void CalcKOW();
     void To3D();
     void CalcName();
@@ -115,6 +117,10 @@ public slots:
     void clearAllGroups();
     void toggleGrid();
     void svXY(int, int);
+    void MagnifyPlus();
+    void MagnifyMinus();
+    void Magnify100();
+    void Zoom(int);
 
     void OBGetFilters();
     void OBImport();
@@ -155,7 +161,7 @@ private:
       *leftJustify, *centerJustify, *rightJustify;
     QComboBox *colorList, *fontList, *fontSizeList, *ltList;
     QStringList ringlist, symbollist, arrowlist, curvearrowlist, bracketlist;
-    QStringList filters;
+    QStringList filters, readFilters, writeFilters;
 };
 
 
