@@ -28,37 +28,46 @@ using namespace OpenBabel;
 
 // OpenBabel functions.
 void ApplicationWindow::OBGetFilters() {
-  //QStringList filters;
   io_type inFileType = UNDEFINED;
   int i;
   OBFileFormat fileFormat;
   QString str1;
   str1 = tr("--Select a filter-- (*)");
-  filters.append(str1);
+  readFilters.append(str1);
+  writeFilters.append(str1);
   str1 = tr("CDXML - ChemDraw text/XML format (*)");
-  filters.append(str1);
+  readFilters.append(str1);
+  writeFilters.append(str1);
   str1 = tr("CDX - ChemDraw binary format (*)");
-  filters.append(str1);
+  readFilters.append(str1);
+  writeFilters.append(str1);
   str1 = tr("XDC - XDrawChem native format (*)");
-  filters.append(str1);
+  readFilters.append(str1);
+  writeFilters.append(str1);
   for (i = 0; i < extab.Count(); i++) {
     str1 = "";
+    str1.append(extab.GetExtension(i));
+    str1.append(": ");
+    str1.append(extab.GetDescription(i));
+    str1.append(" (*)");
+    filters.append(str1);
     if (extab.IsReadable(i)) {
-      str1.append(extab.GetExtension(i));
-      str1.append(": ");
-      str1.append(extab.GetDescription(i));
-      str1.append(" (*)");
-      filters.append(str1);
+      readFilters.append(str1);
+    }
+    if (extab.IsWritable(i)) {
+      writeFilters.append(str1);
     }
   }
   filters.sort();
+  readFilters.sort();
+  writeFilters.sort();
 }
 
 void ApplicationWindow::OBImport() {
   QFileDialog fd(QString::null, QString::null, 0, 0, TRUE);
   fd.setCaption( tr("Open file...") );
   fd.setMode(QFileDialog::ExistingFile);
-  fd.setFilters(filters);  
+  fd.setFilters(readFilters);  
   if ( fd.exec() == QDialog::Accepted ) {
     OBNewLoad(fd.selectedFile(), fd.selectedFilter());
   }
@@ -134,13 +143,18 @@ void ApplicationWindow::OBExport() {
   int i;
   OBFileFormat fileFormat;
   char *formatOptions;
+  QFile ftest;
 
   QFileDialog fd(QString::null, QString::null, 0, 0, TRUE);
   QString str1;
   fd.setCaption( tr("Save file as...") );
   fd.setMode(QFileDialog::AnyFile);
-  fd.setFilters(filters);  
+  fd.setFilters(writeFilters);  
   if ( fd.exec() == QDialog::Accepted ) {
+    if (ftest.exists(fd.selectedFile())) {
+      i = QMessageBox::warning(this, tr("Overwrite file?"), tr("Overwrite existing file: %1 ?").arg(fd.selectedFile()), QMessageBox::Ok, QMessageBox::Cancel);
+      if (i == QMessageBox::Cancel) return;
+    }
     str1 = fd.selectedFilter();
     if (str1.left(2) == "--") {
       str1 = OBGuessFileType(fd.selectedFile());
