@@ -25,6 +25,7 @@ Bond::Bond(Render2D *r1, QObject *parent, const char *name)
   highlighted = false;
   thick = 1;
   wside = 0;
+  auto_wside = 1;
   IR_shift = -100.0;
   IR_intensity = "NA";
 }
@@ -57,14 +58,24 @@ bool Bond::WithinRect(QRect n, bool shiftdown) {
 }
 
 void Bond::Edit() {
+  int db1 = 0;
   cout << "edit bond" << endl;
   BondEditDialog be(r, "bond editor", start, end, TYPE_BOND, order, dashed, thick, 0, color);
+  if (auto_wside == 0) db1 = wside;
+  be.SetDoubleBond(db1);
   if ( !be.exec() ) return;
   cout << "change" << endl;
   color = be.Color();
   order = be.Order();
   dashed = be.Dash();
   thick = be.Thick();
+  db1 = be.DoubleBond();
+  if (db1 == 0) {
+    auto_wside = 1;
+  } else {
+    auto_wside = 0;
+    wside = db1;
+  }
 }
 
 void Bond::Render()
@@ -110,10 +121,10 @@ void Bond::Render()
   // x1, y1, 3 and 4 are for use with special case 1 below 
   x1 = cos(myangle) * 2.5 * offs;
   y1 = sin(myangle) * 2.5 * offs;
-  QPoint sp3( lround(start->x + x1), lround(start->y + y1) );
-  QPoint ep3( lround(end->x + x1), lround(end->y + y1) ); 
-  QPoint sp4( lround(start->x - x1), lround(start->y - y1) ); 
-  QPoint ep4( lround(end->x - x1), lround(end->y - y1) );
+  QPoint sp3( my_round(start->x + x1), my_round(start->y + y1) );
+  QPoint ep3( my_round(end->x + x1), my_round(end->y + y1) ); 
+  QPoint sp4( my_round(start->x - x1), my_round(start->y - y1) ); 
+  QPoint ep4( my_round(end->x - x1), my_round(end->y - y1) );
   // shorten lines by removing from each end
   double bl = start->distanceTo(end);
   if (bl < 100.0) cf = 0.03;
@@ -138,7 +149,7 @@ void Bond::Render()
   ly = start->y - y2 + rise * (1.0 - cf);
   QPoint ep2((int)lx, (int)ly);
 
-  // check for order 2 special case
+  // check for order 2 special case (center double bond)
   bool special_case_1 = false;
   if (order == 2) {
     //cout << "start->element: " << start->element << endl;
@@ -159,6 +170,8 @@ void Bond::Render()
       special_case_1 = true;
     if ((start->element == "N") && (end->element == "N"))
       special_case_1 = true;
+    if (wside == 2)  // force centered double bond
+      special_case_1 = true;
   }
   if (special_case_1 == true) {
     if (dashed > 1)
