@@ -8,22 +8,25 @@ extern QString RingDir;
 
 // version string (makes updates easier :)
 #ifdef UNIX
-#define XDC_VERSION "XDrawChem 1.7.8"
+#define XDC_VERSION "XDrawChem 1.8.5"
 #endif
 
 #ifdef WIN32
-#define XDC_VERSION "WinDrawChem 1.7.8"
+#define XDC_VERSION "WinDrawChem 1.8.5"
 #endif
 
 #ifdef MACOSX
-#define XDC_VERSION "MacDrawChem 1.7.8"
+#define XDC_VERSION "MacDrawChem 1.8.5"
 #endif
 
 // define XDC_SERVER for Windows
 #ifndef UNIX
-#define XDC_SERVER "herger.ibb.gatech.edu"
+#define XDC_SERVER "www.xdrawchem.org"
 #endif
 
+// lround() for all platforms (I hope!)
+int my_round(double);
+
 // units
 #define PIXELS 0
 #define ENGLISH 1
@@ -113,6 +116,7 @@ extern QString RingDir;
 #define MODE_TOOL_GROUP_CLEAR 620
 #define MODE_TOOL_2D3D 630
 #define MODE_TOOL_PKA 640
+#define MODE_TOOL_PARTIAL_CHARGE 641
 #define MODE_TOOL_KOW 650
 #define MODE_TOOL_RETRO 660
 #define MODE_TOOL_RETRO_BONDNAME 699
@@ -149,6 +153,12 @@ extern QString RingDir;
 #define BRACKET_BRACE   3
 #define BRACKET_BOX     4
 #define BRACKET_ELLIPSE 5
+#define BRACKET_CLOSEDSQUARE  6
+#define BRACKET_CIRCLE  7
+#define BRACKET_BOX_SHADOW 8
+#define BRACKET_ELLIPSE_SHADOW 9
+#define BRACKET_SQUARE_SHADOW 10
+#define BRACKET_CIRCLE_SHADOW 11
 
 // arrow styles (Arrow::style)
 #define ARROW_REGULAR 1
