@@ -1,6 +1,7 @@
 #ifndef MIDIALOG_H
 #define MIDIALOG_H
 
+#include <iostream>
 #include <qdialog.h>
 #include <qcombobox.h>
 #include <qlineedit.h>
@@ -23,15 +24,28 @@ public:
     ef += s1;
     ef_check->setText(ef); 
   }
-  void setEA(QString s1) { ea_label->setText(s1); }
+  void setEA(QString s1) { 
+    //ea_label->setText(s1); 
+  }
+  void setCAS(QString s1) { 
+    if (s1 != "unknown") {
+      cas_label->setText(tr("CAS:") + s1);
+    } 
+  }
+  void setName(QString s1) { 
+    std::cout << s1 << std:: endl;
+    if (s1 != "unknown") {
+      name_label->setText(tr("Name:") + s1);
+    } 
+  }
 
   public slots:
     void SendHelp();
 
  private:
   QCheckBox *mw_check, *ef_check, *dg_check;
-  QLabel *ea_label;
-  QString mw, ea, ef, dg;
+  QLabel *ea_label, *name_label, *cas_label;
+  QString mw, ea, ef, dg, casno;
 };
 
 #endif
