@@ -14,9 +14,11 @@ public:
   NetAccess();
   QStringList getChoices(QString, QString, QString, bool);
   QString getFile(QString, QString);
+  QString getCanonicalSmiles(QString, QString);
   QString Rearrange(QString);
+  bool getNameCAS(QString, QString);
   bool status;
-  QString htfile;
+  QString htfile, sname, scas;
   QUrlOperator op;
 
   public slots:
