@@ -12,9 +12,9 @@ class NetDialog:public QDialog {
   NetDialog(QWidget *parent, QString name);
   QString getKey() { 
     QString ret;
-    if (keylist->currentItem() == 0) ret = "CAS-Number";
-    if (keylist->currentItem() == 1) ret = "Formula";
-    if (keylist->currentItem() == 2) ret = "Name";
+    if (keylist->currentItem() == 0) ret = "cas";
+    if (keylist->currentItem() == 1) ret = "formula";
+    if (keylist->currentItem() == 2) ret = "name";
     return ret;
   }
   QString getValue() { return searchkey->text(); }
