@@ -17,6 +17,8 @@ using std::endl;
 #include <qcolor.h>
 #include <qfile.h>
 #include <qtextstream.h>
+#include <qdatetime.h>
+#include <qprocess.h>
 
 #include "defs.h"
 #include "render2d.h"
@@ -52,6 +54,7 @@ Render2D::Render2D(QWidget *parent, const char *name)
   localtext = 0;
 
   thick = 1;
+  zoomFactor = 1.0;
 
   currentFont = QFont("Helvetica", 12);
   currentColor = QColor(0,0,0);
@@ -220,6 +223,8 @@ void Render2D::setMode_DrawBracket(QString btype) {
   if (btype == "BRACE") bracket_type = BRACKET_BRACE;
   if (btype == "BOX") bracket_type = BRACKET_BOX;
   if (btype == "ELLIPSE") bracket_type = BRACKET_ELLIPSE;
+  if (btype == "CLOSEDSQUARE") bracket_type = BRACKET_CLOSEDSQUARE;
+  if (btype == "CIRCLE") bracket_type = BRACKET_CIRCLE;
   emit SignalSetStatusBar( tr("Draw Bracket mode: left click to draw bracket") );
   repaint(false);
 }
@@ -370,7 +375,7 @@ void Render2D::Tool(int t) {
     emit SignalSetStatusBar( tr("Click on a molecule to generate 3-D coordinates") );
     break;
   case MODE_TOOL_NAME:
-    emit SignalSetStatusBar( tr("Click on a molecule to determine its IUPAC name") );
+    emit SignalSetStatusBar( tr("Click on a molecule to guess its name") );
     break;
   case MODE_TOOL_TOSMILES:
     emit SignalSetStatusBar( tr("Click on a molecule to determine its SMILES string") );
@@ -630,6 +635,31 @@ bool Render2D::SaveSVG(QString fn) {
 }
 
 bool Render2D::SaveEPS(QString fn) {
+  //
+  // perhaps look at printing using QPrinter, then shelling to use ps2epsi?
+  //
+  // tmp_fn = xdc[procno].ps
+  QString n1;
+  srand(QTime::currentTime().second());
+  n1.setNum(rand());
+  QString tmp_fn = QString("/tmp/xdc") + n1 + QString(".ps");
+  Print(tmp_fn);
+  // shell (ps2epsi tmp_fn fn)
+  QProcess *proc1 = new QProcess( this );
+  proc1->addArgument( "ps2epsi" );
+  proc1->addArgument( tmp_fn );
+  proc1->addArgument( fn );
+  proc1->start();
+  do {
+    // nothing!
+  } while (proc1->normalExit() == false);
+  QProcess *proc2 = new QProcess( this );
+  proc2->addArgument( "rm" );
+  proc2->addArgument( tmp_fn );
+  proc2->start();
+  return true;
+
+  /*
   outputDevice = OUTPUT_EPS;
   output_file.setName(fn);
   // open file and create text stream
@@ -666,4 +696,31 @@ bool Render2D::SaveEPS(QString fn) {
   outputDevice = OUTPUT_SCREEN;
   repaint(false);
   return true;
+  */
+}
+
+QPoint Render2D::zoomCorrect(QPoint in1) {
+  QPoint out1;
+  double dx = (double)in1.x();
+  double dy = (double)in1.y();
+
+  dx *= zoomFactor;
+  dy *= zoomFactor;
+
+  out1.setX( my_round(dx) );
+  out1.setY( my_round(dy) );
+  return out1;
+}
+
+QPoint Render2D::zoomCorrectReverse(QPoint in1) {
+  QPoint out1;
+  double dx = (double)in1.x();
+  double dy = (double)in1.y();
+
+  dx /= zoomFactor;
+  dy /= zoomFactor;
+
+  out1.setX( my_round(dx) );
+  out1.setY( my_round(dy) );
+  return out1;
 }
