@@ -94,6 +94,7 @@ void Render2D::drawLine(QPoint a, QPoint b, int t, QColor c1, int s) {
     p.begin(this);
   else
     p.begin(&dbuffer);
+  p.scale(zoomFactor, zoomFactor);
   if (s == 0) // solid
     //p.setPen(QPen(c1, t - 1));
     p.setPen(QPen(c1, t));
@@ -118,6 +119,7 @@ void Render2D::drawBezier(QPointArray a1, QColor c1, bool drawPoints,
     p.begin(this);
   else
     p.begin(&dbuffer);
+  p.scale(zoomFactor, zoomFactor);
   p.setPen(c1);
   int xp1, yp1;
   if (drawPoints) {
@@ -138,10 +140,10 @@ void Render2D::drawBezier(QPointArray a1, QColor c1, bool drawPoints,
     double newang1 = ang + 30.0;
     double newang2 = ang - 30.0;
   
-    QPoint p1( lround(ar2.x() + (cos(newang1/MOL_ARAD) * 10.0)),
-	       lround(ar2.y() + (sin(newang1/MOL_ARAD) * 10.0)) );
-    QPoint p2( lround(ar2.x() + (cos(newang2/MOL_ARAD) * 10.0)),
-	       lround(ar2.y() + (sin(newang2/MOL_ARAD) * 10.0)) );
+    QPoint p1( my_round(ar2.x() + (cos(newang1/MOL_ARAD) * 10.0)),
+	       my_round(ar2.y() + (sin(newang1/MOL_ARAD) * 10.0)) );
+    QPoint p2( my_round(ar2.x() + (cos(newang2/MOL_ARAD) * 10.0)),
+	       my_round(ar2.y() + (sin(newang2/MOL_ARAD) * 10.0)) );
 
     if (arrowHead > 0) {
       // draw half arrowhead
@@ -171,13 +173,13 @@ void Render2D::drawBracket(QPoint a, QPoint b, QColor c1, int type) {
   QPoint bl(tl_x, br_y);
   QPoint tr(br_x, tl_y);
   QPoint br(br_x, br_y);
-  if (type == BRACKET_BOX) {
+  if ( (type == BRACKET_BOX) || (type == BRACKET_CLOSEDSQUARE)) {
     drawLine(tl, bl, 1, c1);
     drawLine(bl, br, 1, c1);
     drawLine(tr, br, 1, c1);
     drawLine(tl, tr, 1, c1);
   }
-  if (type == BRACKET_ELLIPSE) {
+  if ( (type == BRACKET_ELLIPSE) || (type == BRACKET_CIRCLE)) {
     QPointArray el;
     el.makeEllipse(tl.x(), tl.y(), br.x() - tl.x(), br.y() - tl.y() );
     drawPolyline(el, c1);
@@ -185,10 +187,10 @@ void Render2D::drawBracket(QPoint a, QPoint b, QColor c1, int type) {
   if (type == BRACKET_SQUARE) {
     drawLine(tl, bl, 1, c1);
     drawLine(tr, br, 1, c1);
-    drawLine(tl, QPoint(tl_x + lround(sf), tl_y), 1, c1);
-    drawLine(bl, QPoint(tl_x + lround(sf), br_y), 1, c1);
-    drawLine(tr, QPoint(br_x - lround(sf), tl_y), 1, c1);
-    drawLine(br, QPoint(br_x - lround(sf), br_y), 1, c1);
+    drawLine(tl, QPoint(tl_x + my_round(sf), tl_y), 1, c1);
+    drawLine(bl, QPoint(tl_x + my_round(sf), br_y), 1, c1);
+    drawLine(tr, QPoint(br_x - my_round(sf), tl_y), 1, c1);
+    drawLine(br, QPoint(br_x - my_round(sf), br_y), 1, c1);
   }
   if (type == BRACKET_CURVE) {
     // calculate center of circle
@@ -203,29 +205,29 @@ void Render2D::drawBracket(QPoint a, QPoint b, QColor c1, int type) {
     ang1 = 90.0 - ang1;
     ang1 *= 16.0;
     QPointArray pa;
-    pa.makeArc( lround(box_x), lround(box_y), lround(wx * 2.0), 
-		lround(wx * 2.0), lround(-ang1), lround(2.0 * ang1) );
+    pa.makeArc( my_round(box_x), my_round(box_y), my_round(wx * 2.0), 
+		my_round(wx * 2.0), my_round(-ang1), my_round(2.0 * ang1) );
     drawPolyline(pa, c1);
-    pa.makeArc( lround(box_x), lround(box_y), lround(wx * 2.0), 
-	        lround(wx * 2.0), lround(-ang1 + 2880.0), lround(2.0 * ang1) );
+    pa.makeArc( my_round(box_x), my_round(box_y), my_round(wx * 2.0), 
+	        my_round(wx * 2.0), my_round(-ang1 + 2880.0), my_round(2.0 * ang1) );
     drawPolyline(pa, c1);
   }
   if (type == BRACKET_BRACE) {
-    drawLine(QPoint(tl_x + lround(sf2), tl_y), 
-	     QPoint(tl_x + lround(sf2), br_y), 1, c1);
-    drawLine(QPoint(br_x - lround(sf2), tl_y), 
-	     QPoint(br_x - lround(sf2), br_y), 1, c1);
-    drawLine(QPoint(tl_x + lround(sf2), tl_y), 
-	     QPoint(tl_x + lround(sf), tl_y), 1, c1);
-    drawLine(QPoint(tl_x + lround(sf2), br_y), 
-	     QPoint(tl_x + lround(sf), br_y), 1, c1);
-    drawLine(QPoint(br_x - lround(sf2), tl_y), 
-	     QPoint(br_x - lround(sf), tl_y), 1, c1);
-    drawLine(QPoint(br_x - lround(sf2), br_y), 
-	     QPoint(br_x - lround(sf), br_y), 1, c1);
+    drawLine(QPoint(tl_x + my_round(sf2), tl_y), 
+	     QPoint(tl_x + my_round(sf2), br_y), 1, c1);
+    drawLine(QPoint(br_x - my_round(sf2), tl_y), 
+	     QPoint(br_x - my_round(sf2), br_y), 1, c1);
+    drawLine(QPoint(tl_x + my_round(sf2), tl_y), 
+	     QPoint(tl_x + my_round(sf), tl_y), 1, c1);
+    drawLine(QPoint(tl_x + my_round(sf2), br_y), 
+	     QPoint(tl_x + my_round(sf), br_y), 1, c1);
+    drawLine(QPoint(br_x - my_round(sf2), tl_y), 
+	     QPoint(br_x - my_round(sf), tl_y), 1, c1);
+    drawLine(QPoint(br_x - my_round(sf2), br_y), 
+	     QPoint(br_x - my_round(sf), br_y), 1, c1);
     double midy = (tl_y + br_y) / 2.0;
-    drawLine(QPoint(tl_x, lround(midy) ), QPoint(tl_x + lround(sf2), lround(midy) ), 1, c1);
-    drawLine(QPoint(br_x, lround(midy) ), QPoint(br_x - lround(sf2), lround(midy) ), 1, c1);
+    drawLine(QPoint(tl_x, my_round(midy) ), QPoint(tl_x + my_round(sf2), my_round(midy) ), 1, c1);
+    drawLine(QPoint(br_x, my_round(midy) ), QPoint(br_x - my_round(sf2), my_round(midy) ), 1, c1);
   }
 }
 
@@ -251,7 +253,7 @@ void Render2D::drawWavyLine(QPoint a, QPoint b, QColor c1) {
   double dx = b.x() - a.x();
   double dy = b.y() - a.y();
   double dmag = sqrt(dx*dx + dy*dy);
-  int nwaves = lround(dmag / 6.0);
+  int nwaves = my_round(dmag / 6.0);
   double wwidth = dmag / (double)nwaves;
   int cn, lx, ly;
   double dx1, dy1, ia_rad, dx2, dy2;
@@ -330,7 +332,7 @@ void Render2D::drawUpLine(QPoint a, QPoint b, QColor c1) {
     p.begin(this);
   else
     p.begin(&dbuffer);
-  //QPainter p(&dbuffer);
+  p.scale(zoomFactor, zoomFactor);
   p.setPen(c1);
   p.setBrush(QBrush(c1));
   QPointArray triangle(3);
@@ -344,14 +346,14 @@ void Render2D::drawDownLine(QPoint a, QPoint b, QColor c1) {
   double ang = getAngle(a, b);
   double dx = b.x() - a.x();
   double dy = b.y() - a.y();
-  double angvar = asin(3.0 / sqrt(dx*dx + dy*dy)) * 180 / M_PI;
+  double angvar = asin(4.0 / sqrt(dx*dx + dy*dy)) * 180 / M_PI;
   double newang1 = ang + angvar;
   double newang2 = ang - angvar;
   double newlen = sqrt(dx*dx + dy*dy);
-	QPoint t1, t2;
+  QPoint t1, t2;
 
   for (double scalefactor = 1.0; scalefactor < newlen; scalefactor = 
-	 scalefactor + 4.0) {
+	 scalefactor + 3.0) {
     dx = scalefactor * cos(newang1 / MOL_ARAD);
     dy = scalefactor * sin(newang1 / MOL_ARAD);
     t1.setX( (a.x() + (int)dx) ); 
@@ -385,15 +387,15 @@ void Render2D::drawArrow(QPoint a, QPoint b, QColor c1, int s1) {
   double newang3 = oppang + 30.0;
   double newang4 = oppang - 30.0;
 
-  QPoint a1( lround(b.x() + (cos(newang1/MOL_ARAD) * 10.0)),
-	     lround(b.y() + (sin(newang1/MOL_ARAD) * 10.0)) );
-  QPoint a2( lround(b.x() + (cos(newang2/MOL_ARAD) * 10.0)),
-	     lround(b.y() + (sin(newang2/MOL_ARAD) * 10.0)) );
+  QPoint a1( my_round(b.x() + (cos(newang1/MOL_ARAD) * 10.0)),
+	     my_round(b.y() + (sin(newang1/MOL_ARAD) * 10.0)) );
+  QPoint a2( my_round(b.x() + (cos(newang2/MOL_ARAD) * 10.0)),
+	     my_round(b.y() + (sin(newang2/MOL_ARAD) * 10.0)) );
 
-  QPoint a3( lround(a.x() + (cos(newang3/MOL_ARAD) * 10.0)),
-	     lround(a.y() + (sin(newang3/MOL_ARAD) * 10.0)) );
-  QPoint a4( lround(a.x() + (cos(newang4/MOL_ARAD) * 10.0)),
-	     lround(a.y() + (sin(newang4/MOL_ARAD) * 10.0)) );
+  QPoint a3( my_round(a.x() + (cos(newang3/MOL_ARAD) * 10.0)),
+	     my_round(a.y() + (sin(newang3/MOL_ARAD) * 10.0)) );
+  QPoint a4( my_round(a.x() + (cos(newang4/MOL_ARAD) * 10.0)),
+	     my_round(a.y() + (sin(newang4/MOL_ARAD) * 10.0)) );
 
   if (s1 == ARROW_REGULAR) {
     drawLine(a, b, 1, c1);
@@ -406,14 +408,14 @@ void Render2D::drawArrow(QPoint a, QPoint b, QColor c1, int s1) {
     double newang6 = ang - 45.0;
     double newang7 = oppang + 45.0;
     double newang8 = oppang - 45.0;
-    QPoint a5( lround(m1.x() + (cos(newang5/MOL_ARAD) * 10.0)),
-	       lround(m1.y() + (sin(newang5/MOL_ARAD) * 10.0)) );
-    QPoint a6( lround(m1.x() + (cos(newang6/MOL_ARAD) * 10.0)),
-	       lround(m1.y() + (sin(newang6/MOL_ARAD) * 10.0)) );
-    QPoint a7( lround(m1.x() + (cos(newang7/MOL_ARAD) * 10.0)),
-	       lround(m1.y() + (sin(newang7/MOL_ARAD) * 10.0)) );
-    QPoint a8( lround(m1.x() + (cos(newang8/MOL_ARAD) * 10.0)),
-	       lround(m1.y() + (sin(newang8/MOL_ARAD) * 10.0)) );
+    QPoint a5( my_round(m1.x() + (cos(newang5/MOL_ARAD) * 10.0)),
+	       my_round(m1.y() + (sin(newang5/MOL_ARAD) * 10.0)) );
+    QPoint a6( my_round(m1.x() + (cos(newang6/MOL_ARAD) * 10.0)),
+	       my_round(m1.y() + (sin(newang6/MOL_ARAD) * 10.0)) );
+    QPoint a7( my_round(m1.x() + (cos(newang7/MOL_ARAD) * 10.0)),
+	       my_round(m1.y() + (sin(newang7/MOL_ARAD) * 10.0)) );
+    QPoint a8( my_round(m1.x() + (cos(newang8/MOL_ARAD) * 10.0)),
+	       my_round(m1.y() + (sin(newang8/MOL_ARAD) * 10.0)) );
     drawLine(a, b, 1, c1);
     drawLine(b, a1, 1, c1);
     drawLine(b, a2, 1, c1);
@@ -442,14 +444,14 @@ void Render2D::drawArrow(QPoint a, QPoint b, QColor c1, int s1) {
     if (offs > 2.0) offs = 2.0;
     x2 = cos(myangle) * 2.5 * offs;
     y2 = sin(myangle) * 2.5 * offs;
-    QPoint sp1( lround(a.x() + x2), lround(a.y() + y2) );
-    QPoint ep1( lround(b.x() + x2), lround(b.y() + y2) ); 
-    QPoint sp2( lround(a.x() - x2), lround(a.y() - y2) ); 
-    QPoint ep2( lround(b.x() - x2), lround(b.y() - y2) ); 
-    QPoint a8( lround(ep2.x() + (cos(newang1/MOL_ARAD) * 10.0)),
-	       lround(ep2.y() + (sin(newang1/MOL_ARAD) * 10.0)) );
-    QPoint a9( lround(sp1.x() + (cos(newang3/MOL_ARAD) * 10.0)),
-	       lround(sp1.y() + (sin(newang3/MOL_ARAD) * 10.0)) );
+    QPoint sp1( my_round(a.x() + x2), my_round(a.y() + y2) );
+    QPoint ep1( my_round(b.x() + x2), my_round(b.y() + y2) ); 
+    QPoint sp2( my_round(a.x() - x2), my_round(a.y() - y2) ); 
+    QPoint ep2( my_round(b.x() - x2), my_round(b.y() - y2) ); 
+    QPoint a8( my_round(ep2.x() + (cos(newang1/MOL_ARAD) * 10.0)),
+	       my_round(ep2.y() + (sin(newang1/MOL_ARAD) * 10.0)) );
+    QPoint a9( my_round(sp1.x() + (cos(newang3/MOL_ARAD) * 10.0)),
+	       my_round(sp1.y() + (sin(newang3/MOL_ARAD) * 10.0)) );
     drawLine(sp1, ep1, 1, c1);
     drawLine(ep2, a8, 1, c1);
     drawLine(sp2, ep2, 1, c1);
@@ -463,26 +465,26 @@ void Render2D::drawArrow(QPoint a, QPoint b, QColor c1, int s1) {
     if (offs > 2.0) offs = 2.0;
     x2 = cos(myangle) * 4.0 * offs;
     y2 = sin(myangle) * 4.0 * offs;
-    QPoint sp1( lround(a.x() + x2), lround(a.y() + y2) );
-    QPoint ep1( lround(b.x() + x2), lround(b.y() + y2) ); 
-    QPoint sp2( lround(a.x() - x2), lround(a.y() - y2) ); 
-    QPoint ep2( lround(b.x() - x2), lround(b.y() - y2) );
+    QPoint sp1( my_round(a.x() + x2), my_round(a.y() + y2) );
+    QPoint ep1( my_round(b.x() + x2), my_round(b.y() + y2) ); 
+    QPoint sp2( my_round(a.x() - x2), my_round(a.y() - y2) ); 
+    QPoint ep2( my_round(b.x() - x2), my_round(b.y() - y2) );
     double dx = ep1.x() - sp1.x();
     double dy = ep1.y() - sp1.y();
     dx = dx / DistanceBetween(sp1, ep1);
     dy = dy / DistanceBetween(sp1, ep1);
     dx = dx * (DistanceBetween(sp1, ep1) - (4.0 * offs));
     dy = dy * (DistanceBetween(sp1, ep1) - (4.0 * offs));
-    ep1.setX( lround(sp1.x() + dx) );
-    ep1.setY( lround(sp1.y() + dy) );
-    ep2.setX( lround(sp2.x() + dx) );
-    ep2.setY( lround(sp2.y() + dy) );
+    ep1.setX( my_round(sp1.x() + dx) );
+    ep1.setY( my_round(sp1.y() + dy) );
+    ep2.setX( my_round(sp2.x() + dx) );
+    ep2.setY( my_round(sp2.y() + dy) );
     double newang5 = ang + 45.0;
     double newang6 = ang - 45.0;
-    QPoint a8( lround(b.x() + (cos(newang5/MOL_ARAD) * 10.0 * offs)),
-	       lround(b.y() + (sin(newang5/MOL_ARAD) * 10.0 * offs)) );
-    QPoint a9( lround(b.x() + (cos(newang6/MOL_ARAD) * 10.0 * offs)),
-	       lround(b.y() + (sin(newang6/MOL_ARAD) * 10.0 * offs)) );
+    QPoint a8( my_round(b.x() + (cos(newang5/MOL_ARAD) * 10.0 * offs)),
+	       my_round(b.y() + (sin(newang5/MOL_ARAD) * 10.0 * offs)) );
+    QPoint a9( my_round(b.x() + (cos(newang6/MOL_ARAD) * 10.0 * offs)),
+	       my_round(b.y() + (sin(newang6/MOL_ARAD) * 10.0 * offs)) );
     drawLine(sp1, ep1, 1, c1);
     drawLine(sp2, ep2, 1, c1);
     drawLine(sp1, sp2, 1, c1);
@@ -497,7 +499,7 @@ void Render2D::drawBox(QPoint a, QPoint b, QColor c1) {
     p.begin(this);
   else
     p.begin(&dbuffer);
-  //QPainter p(&dbuffer);
+  p.scale(zoomFactor, zoomFactor);
   p.setPen(c1);
   p.drawRect(QRect(a, b));
 }
@@ -548,7 +550,7 @@ void Render2D::drawFillBox(QPoint a, QPoint b, QColor c1, bool border,
     p.begin(this);
   else
     p.begin(&dbuffer);
-  //QPainter p(&dbuffer);
+  p.scale(zoomFactor, zoomFactor);
   p.setPen(c1);
   p.fillRect(QRect(a, b), c1);
   if (border) {
@@ -564,7 +566,7 @@ void Render2D::drawCircle(QPoint a, int rad, QColor cfill) {
     p.begin(this);
   else
     p.begin(&dbuffer);
-  //QPainter p(&dbuffer);
+  p.scale(zoomFactor, zoomFactor);
   p.setBrush(cfill);
   p.setPen(QColor(0,0,0));
   p.drawEllipse(a.x(), a.y(), rad * 2, rad * 2);
@@ -628,7 +630,7 @@ void Render2D::drawText(QChar ch, QPoint a, QColor c1, QFont f) {
     p.begin(this);
   else
     p.begin(&dbuffer);
-  //QPainter p(&dbuffer);
+  p.scale(zoomFactor, zoomFactor);
   p.setPen(c1);
   p.setFont(f);
   p.drawText(a, ch);
@@ -671,7 +673,7 @@ void Render2D::drawString(QString s1, QPoint a, QColor c1, QFont f) {
     p.begin(this);
   else
     p.begin(&dbuffer);
-  //QPainter p(&dbuffer);
+  p.scale(zoomFactor, zoomFactor);
   p.setPen(c1);
   p.setFont(f);
   p.drawText(a, s1);
@@ -683,7 +685,7 @@ void Render2D::drawTextReverse(QChar ch, QPoint a, QColor c1, QFont f) {
     p.begin(this);
   else
     p.begin(&dbuffer);
-  //QPainter p(&dbuffer);
+  p.scale(zoomFactor, zoomFactor);
   p.setPen(c1);
   p.setFont(f);
   QFontMetrics fm = p.fontMetrics();
@@ -738,7 +740,7 @@ void Render2D::drawPixmap(QPoint a, QPixmap pix) {
     p.begin(this);
   else
     p.begin(&dbuffer);
-  //QPainter p(&dbuffer);
+  p.scale(zoomFactor, zoomFactor);
   p.drawPixmap(a, pix);
 }
 
@@ -769,7 +771,7 @@ void Render2D::drawCurveArrow(QPoint a, QPoint b, QColor c1, QString wh) {
     p.begin(this);
   else
     p.begin(&dbuffer);
-  //QPainter p(&dbuffer);
+  p.scale(zoomFactor, zoomFactor);
   p.setPen(c1);
   if (wh == "CW180") {
     // calculate curve
@@ -777,7 +779,7 @@ void Render2D::drawCurveArrow(QPoint a, QPoint b, QColor c1, QString wh) {
     int d = RoundOff(DistanceBetween(a, ce));
     double sa = getAngle(ce, a);
     QPointArray pa;
-    pa.makeArc(ce.x() - d, ce.y() - d, 2*d, 2*d, lround(-sa*16), -2880);
+    pa.makeArc(ce.x() - d, ce.y() - d, 2*d, 2*d, my_round(-sa*16), -2880);
     drawPolyline(pa, c1);
     // calculate arrowhead
     // if curve too small, don't draw arrowhead
@@ -786,10 +788,10 @@ void Render2D::drawCurveArrow(QPoint a, QPoint b, QColor c1, QString wh) {
     sa = getAngle(b, a);
     double newang1 = sa + 60.0;
     double newang2 = sa + 120.0;
-    QPoint a1( lround(realb.x() + (cos(newang1/MOL_ARAD) * 10.0)),
-	       lround(realb.y() + (sin(newang1/MOL_ARAD) * 10.0)) );
-    QPoint a2( lround(realb.x() + (cos(newang2/MOL_ARAD) * 10.0)),
-	       lround(realb.y() + (sin(newang2/MOL_ARAD) * 10.0)) );
+    QPoint a1( my_round(realb.x() + (cos(newang1/MOL_ARAD) * 10.0)),
+	       my_round(realb.y() + (sin(newang1/MOL_ARAD) * 10.0)) );
+    QPoint a2( my_round(realb.x() + (cos(newang2/MOL_ARAD) * 10.0)),
+	       my_round(realb.y() + (sin(newang2/MOL_ARAD) * 10.0)) );
     drawLine(realb, a1, 1, c1);
     drawLine(realb, a2, 1, c1);
   }
@@ -799,7 +801,7 @@ void Render2D::drawCurveArrow(QPoint a, QPoint b, QColor c1, QString wh) {
     int d = RoundOff(DistanceBetween(a, ce));
     double sa = getAngle(ce, a);
     QPointArray pa;
-    pa.makeArc(ce.x() - d, ce.y() - d, 2*d, 2*d, lround(-sa*16), 2880);
+    pa.makeArc(ce.x() - d, ce.y() - d, 2*d, 2*d, my_round(-sa*16), 2880);
     drawPolyline(pa, c1);
     // calculate arrowhead
     // if curve too small, don't draw arrowhead
@@ -808,10 +810,10 @@ void Render2D::drawCurveArrow(QPoint a, QPoint b, QColor c1, QString wh) {
     sa = getAngle(b, a);
     double newang1 = sa + 240.0;
     double newang2 = sa + 300.0;
-    QPoint a1( lround(realb.x() + (cos(newang1/MOL_ARAD) * 10.0)),
-	       lround(realb.y() + (sin(newang1/MOL_ARAD) * 10.0)) );
-    QPoint a2( lround(realb.x() + (cos(newang2/MOL_ARAD) * 10.0)),
-	       lround(realb.y() + (sin(newang2/MOL_ARAD) * 10.0)) );
+    QPoint a1( my_round(realb.x() + (cos(newang1/MOL_ARAD) * 10.0)),
+	       my_round(realb.y() + (sin(newang1/MOL_ARAD) * 10.0)) );
+    QPoint a2( my_round(realb.x() + (cos(newang2/MOL_ARAD) * 10.0)),
+	       my_round(realb.y() + (sin(newang2/MOL_ARAD) * 10.0)) );
     drawLine(realb, a1, 1, c1);
     drawLine(realb, a2, 1, c1);
   }
@@ -831,7 +833,7 @@ void Render2D::drawCurveArrow(QPoint a, QPoint b, QColor c1, QString wh) {
     double sa = getAngle(ce, a);
     QPointArray pa;
     int d = RoundOff(d1);
-    pa.makeArc(ce.x() - d, ce.y() - d, 2*d, 2*d, lround(-sa*16), -1440);
+    pa.makeArc(ce.x() - d, ce.y() - d, 2*d, 2*d, my_round(-sa*16), -1440);
     drawPolyline(pa, c1);    
     // calculate arrowhead
     // if curve too small, don't draw arrowhead
@@ -840,10 +842,10 @@ void Render2D::drawCurveArrow(QPoint a, QPoint b, QColor c1, QString wh) {
     sa = getAngle(b, a);
     double newang1 = sa + 15.0;
     double newang2 = sa + 75.0;
-    QPoint a1( lround(realb.x() + (cos(newang1/MOL_ARAD) * 10.0)),
-	       lround(realb.y() + (sin(newang1/MOL_ARAD) * 10.0)) );
-    QPoint a2( lround(realb.x() + (cos(newang2/MOL_ARAD) * 10.0)),
-	       lround(realb.y() + (sin(newang2/MOL_ARAD) * 10.0)) );
+    QPoint a1( my_round(realb.x() + (cos(newang1/MOL_ARAD) * 10.0)),
+	       my_round(realb.y() + (sin(newang1/MOL_ARAD) * 10.0)) );
+    QPoint a2( my_round(realb.x() + (cos(newang2/MOL_ARAD) * 10.0)),
+	       my_round(realb.y() + (sin(newang2/MOL_ARAD) * 10.0)) );
     drawLine(realb, a1, 1, c1);
     drawLine(realb, a2, 1, c1);
   }
@@ -863,7 +865,7 @@ void Render2D::drawCurveArrow(QPoint a, QPoint b, QColor c1, QString wh) {
     double sa = getAngle(ce, a);
     QPointArray pa;
     int d = RoundOff(d1);
-    pa.makeArc(ce.x() - d, ce.y() - d, 2*d, 2*d, lround(-sa*16), 1440);
+    pa.makeArc(ce.x() - d, ce.y() - d, 2*d, 2*d, my_round(-sa*16), 1440);
     drawPolyline(pa, c1);    
     // calculate arrowhead
     // if curve too small, don't draw arrowhead
@@ -872,10 +874,10 @@ void Render2D::drawCurveArrow(QPoint a, QPoint b, QColor c1, QString wh) {
     sa = getAngle(b, a);
     double newang1 = sa - 15.0;
     double newang2 = sa - 75.0;
-    QPoint a1( lround(realb.x() + (cos(newang1/MOL_ARAD) * 10.0)),
-	       lround(realb.y() + (sin(newang1/MOL_ARAD) * 10.0)) );
-    QPoint a2( lround(realb.x() + (cos(newang2/MOL_ARAD) * 10.0)),
-	       lround(realb.y() + (sin(newang2/MOL_ARAD) * 10.0)) );
+    QPoint a1( my_round(realb.x() + (cos(newang1/MOL_ARAD) * 10.0)),
+	       my_round(realb.y() + (sin(newang1/MOL_ARAD) * 10.0)) );
+    QPoint a2( my_round(realb.x() + (cos(newang2/MOL_ARAD) * 10.0)),
+	       my_round(realb.y() + (sin(newang2/MOL_ARAD) * 10.0)) );
     drawLine(realb, a1, 1, c1);
     drawLine(realb, a2, 1, c1);
   }
@@ -895,7 +897,7 @@ void Render2D::drawCurveArrow(QPoint a, QPoint b, QColor c1, QString wh) {
     double sa = getAngle(ce, a);
     QPointArray pa;
     int d = RoundOff(d1);
-    pa.makeArc(ce.x() - d, ce.y() - d, 2*d, 2*d, lround(-sa*16), -4320);
+    pa.makeArc(ce.x() - d, ce.y() - d, 2*d, 2*d, my_round(-sa*16), -4320);
     drawPolyline(pa, c1);    
     // calculate arrowhead
     // if curve too small, don't draw arrowhead
@@ -904,10 +906,10 @@ void Render2D::drawCurveArrow(QPoint a, QPoint b, QColor c1, QString wh) {
     sa = getAngle(b, a);
     double newang1 = sa + 165.0;
     double newang2 = sa + 105.0;
-    QPoint a1( lround(realb.x() + (cos(newang1/MOL_ARAD) * 10.0)),
-	       lround(realb.y() + (sin(newang1/MOL_ARAD) * 10.0)) );
-    QPoint a2( lround(realb.x() + (cos(newang2/MOL_ARAD) * 10.0)),
-	       lround(realb.y() + (sin(newang2/MOL_ARAD) * 10.0)) );
+    QPoint a1( my_round(realb.x() + (cos(newang1/MOL_ARAD) * 10.0)),
+	       my_round(realb.y() + (sin(newang1/MOL_ARAD) * 10.0)) );
+    QPoint a2( my_round(realb.x() + (cos(newang2/MOL_ARAD) * 10.0)),
+	       my_round(realb.y() + (sin(newang2/MOL_ARAD) * 10.0)) );
     drawLine(realb, a1, 1, c1);
     drawLine(realb, a2, 1, c1);
   }
@@ -927,7 +929,7 @@ void Render2D::drawCurveArrow(QPoint a, QPoint b, QColor c1, QString wh) {
     double sa = getAngle(ce, a);
     QPointArray pa;
     int d = RoundOff(d1);
-    pa.makeArc(ce.x() - d, ce.y() - d, 2*d, 2*d, lround(-sa*16), 4320);
+    pa.makeArc(ce.x() - d, ce.y() - d, 2*d, 2*d, my_round(-sa*16), 4320);
     drawPolyline(pa, c1);    
     // calculate arrowhead
     // if curve too small, don't draw arrowhead
@@ -936,10 +938,10 @@ void Render2D::drawCurveArrow(QPoint a, QPoint b, QColor c1, QString wh) {
     sa = getAngle(b, a);
     double newang1 = sa - 165.0;
     double newang2 = sa - 105.0;
-    QPoint a1( lround(realb.x() + (cos(newang1/MOL_ARAD) * 10.0)),
-	       lround(realb.y() + (sin(newang1/MOL_ARAD) * 10.0)) );
-    QPoint a2( lround(realb.x() + (cos(newang2/MOL_ARAD) * 10.0)),
-	       lround(realb.y() + (sin(newang2/MOL_ARAD) * 10.0)) );
+    QPoint a1( my_round(realb.x() + (cos(newang1/MOL_ARAD) * 10.0)),
+	       my_round(realb.y() + (sin(newang1/MOL_ARAD) * 10.0)) );
+    QPoint a2( my_round(realb.x() + (cos(newang2/MOL_ARAD) * 10.0)),
+	       my_round(realb.y() + (sin(newang2/MOL_ARAD) * 10.0)) );
     drawLine(realb, a1, 1, c1);
     drawLine(realb, a2, 1, c1);
   }
@@ -960,6 +962,8 @@ QPixmap Render2D::MakePixmap(bool transp) {
   mode = MODE_SELECT;  // so selection box will not appear
   finishedPainting = false;
   repaint(true);
+  r.setTopLeft( zoomCorrect(r.topLeft()) );
+  r.setBottomRight( zoomCorrect(r.bottomRight()) );
   QPixmap pm( r.size() );
 
   cout << "X1:" << r.left() << " Y1:" << r.top() << endl;
