@@ -16,6 +16,7 @@ using std::endl;
 #include "text.h"
 #include "defs.h"
 #include "xdc_event.h"
+#include "molinfodialog.h"
 
 // move point to grid if needed
 QPoint Render2D::GridLock(QPoint qp1) {
@@ -24,13 +25,13 @@ QPoint Render2D::GridLock(QPoint qp1) {
   if (mode > 299)
     return qp1;
 
-  int d1 = preferences.getGridSpacing();
+  int d1 = my_round( (double)preferences.getGridSpacing() * zoomFactor );
 
   if (preferences.getDrawGrid() == GRID_SQUARE) {
     double gs = (double)d1, gx = (double)qp1.x(), gy = (double)qp1.y();
     int rx, ry;
-    rx = lround(gx / gs);
-    ry = lround(gy / gs);
+    rx = my_round(gx / gs);
+    ry = my_round(gy / gs);
     qp1.setX(rx * d1);
     qp1.setY(ry * d1);
     
@@ -82,28 +83,74 @@ QPoint Render2D::GridLock(QPoint qp1) {
   return qp1;
 }
 
+// right-click popup choices from mousePressEvent popup (rtclickpopup)
+void Render2D::molInfo() {
+  std::cerr << "Popup-info" << std::endl;
+  DPoint *tmp_pt2 = new DPoint;
+  tmp_pt2->set( targetmol->BoundingBoxAll().center() );
+  c->Tool(tmp_pt2, MODE_TOOL_MOLECULE_INFO);
+}
+void Render2D::molSelect() {
+  DeselectAll();
+  targetmol->SelectAll();
+  selectionBox = c->selectionBox();
+  mode = MODE_SELECT_MULTIPLE_SELECTED;  
+  repaint(false);
+}
+void Render2D::molCut() {
+  DeselectAll();
+  targetmol->SelectAll();
+  Cut();
+  std::cerr << "popup-Cut" << std::endl;
+}
+void Render2D::molCopy() {
+  DeselectAll();
+  targetmol->SelectAll();
+  Copy();
+  DeselectAll();
+  std::cerr << "popup-Copy" << std::endl;
+}
+
 void Render2D::mousePressEvent(QMouseEvent *e1) {
-  QPoint curqpt = e1->pos();
+  QPoint curqpt = zoomCorrectReverse( e1->pos() );
 
   if (preferences.getSnapGrid() != GRID_NONE) {
     curqpt = GridLock(curqpt);
   }
 
-    bool allowedit = false;
-    moved = false;
+  bool allowedit = false;
+  moved = false;
 
-    DPoint tmp_pt(curqpt.x(), curqpt.y());
+  DPoint tmp_pt(curqpt.x(), curqpt.y());
+  DPoint *tmp_pt2 = new DPoint;
+  tmp_pt2->x = curqpt.x(); tmp_pt2->y = curqpt.y();
 
-    if (mode > 100)
-      c->StartUndo(mode, 0);   // BMS: StartUndo does nothing with the point - don't copy!
-    //cout << "Click" << endl;
-    // update button state
-    if (e1->button() == LeftButton)
-        mouse1down = true;
-    if (e1->button() == RightButton) {
-        mouse3down = true;
+  if (mode > 100)
+    c->StartUndo(mode, 0);   // BMS: StartUndo does nothing with the point - don't copy!
+  //cout << "Click" << endl;
+  // update button state
+  if (e1->button() == LeftButton)
+    mouse1down = true;
+  if (e1->button() == RightButton) {
+    mouse3down = true;
+  }
+  //cout << "start at " << curqpt.x() << "," << curqpt.y() << endl;
+
+  if ( (mode == MODE_SELECT) && mouse3down ) {
+    //if (rtclickpopup != 0) delete rtclickpopup;
+    targetmol = c->insideMolecule(tmp_pt2);
+    if (targetmol != 0) {
+      rtclickpopup = new QPopupMenu(this);
+      int id1 = rtclickpopup->insertItem( tr("Molecule") ); 
+      rtclickpopup->setItemEnabled(id1, false);
+      rtclickpopup->insertItem( tr("Info"), this, SLOT(molInfo()) ); 
+      rtclickpopup->insertItem( tr("Select"), this, SLOT(molSelect()) ); 
+      rtclickpopup->insertItem( tr("Cut"), this, SLOT(molCut()) ); 
+      rtclickpopup->insertItem( tr("Copy"), this, SLOT(molCopy()) ); 
+      mouse3down = false;
+      rtclickpopup->popup( mapToGlobal(e1->pos()) );
     }
-    //cout << "start at " << e1->x() << "," << e1->y() << endl;
+  }
 
     // MODE_TEXT: call special function to handle text events
     if (mode == MODE_TEXT) {
@@ -150,8 +197,8 @@ void Render2D::mousePressEvent(QMouseEvent *e1) {
       allowedit = true;
     // get Drawable of nearest object
     DPoint *e = new DPoint;
-    e->x = e1->x();
-    e->y = e1->y();
+    e->x = curqpt.x();
+    e->y = curqpt.y();
     double distobj;
     Drawable *no = c->FindNearestObject(e, distobj);
     if (distobj > 5.0)
@@ -201,7 +248,7 @@ void Render2D::mousePressEvent(QMouseEvent *e1) {
     // MODE_SELECT_MULTIPLE_SELECTED: either move, or deselect all
     if ( (mode == MODE_SELECT_MULTIPLE_SELECTED) && (mouse1down) ) {
         // check for move
-        if (selectionBox.contains( e1->pos() )) {
+        if (selectionBox.contains( curqpt )) {
             c->StartUndo(0,0);
             mode = MODE_SELECT_MOVE_MULTIPLE;
         } else {
@@ -214,7 +261,7 @@ void Render2D::mousePressEvent(QMouseEvent *e1) {
     // MODE_SELECT_MULTIPLE_SELECTED and Button3: Drag and Drop!
     if ( (mode == MODE_SELECT_MULTIPLE_SELECTED) && (mouse3down) ) {
         // check for move
-        if (selectionBox.contains( e1->pos() )) {
+        if (selectionBox.contains( curqpt )) {
             dragging = true;
         } else {
             c->DeselectAll();
@@ -233,7 +280,7 @@ void Render2D::mousePressEvent(QMouseEvent *e1) {
         mode = MODE_SELECT_ROTATE_MULTIPLE;
         rotateOrigin.setX( (selectionBox.right() + selectionBox.left() - 2) / 2);
         rotateOrigin.setY( (selectionBox.bottom() + selectionBox.top()) / 2);
-        prevangle = getAngle( rotateOrigin, e1->pos() );
+        prevangle = getAngle( rotateOrigin, curqpt );
     }
 
     // MODE_DRAWLINE (draw line tool selected), and left button.
@@ -352,9 +399,9 @@ void Render2D::mousePressEvent(QMouseEvent *e1) {
 }
 
 void Render2D::mouseReleaseEvent(QMouseEvent *e1) {
-    DPoint *tmp_pt;
-    XDC_Event *evt;
-  QPoint curqpt = e1->pos();
+  DPoint *tmp_pt;
+  XDC_Event *evt;
+  QPoint curqpt = zoomCorrectReverse( e1->pos() );
 
   if (preferences.getSnapGrid() != GRID_NONE) {
     curqpt = GridLock(curqpt);
@@ -366,7 +413,7 @@ void Render2D::mouseReleaseEvent(QMouseEvent *e1) {
         mouse1down = false;
     if (e1->button() == RightButton)
         mouse3down = false;
-    //cout << "end at " << e1->x() << "," << e1->y() << endl;
+    //cout << "end at " << curqpt.x() << "," << curqpt.y() << endl;
 
     // MODE_TEXT: call special function to handle text events
     if (mode == MODE_TEXT) {
@@ -402,7 +449,7 @@ void Render2D::mouseReleaseEvent(QMouseEvent *e1) {
     // Control-LeftClick invokes Molecule Information window
     if ( (e1->button() == LeftButton) &&
 	 ((e1->state() & ControlButton) == ControlButton) ) {
-      tmp_pt = new DPoint(e1->pos());
+      tmp_pt = new DPoint(curqpt);
       c->Tool(tmp_pt, MODE_TOOL_MOLECULE_INFO);
       repaint(false);
       return;
@@ -413,11 +460,11 @@ void Render2D::mouseReleaseEvent(QMouseEvent *e1) {
       repaint(false);
       directdraw = true;
       if (bezier_count < 3) {
-	tmp_bezier.setPoint(bezier_count, e1->pos().x(), e1->pos().y());
+	tmp_bezier.setPoint(bezier_count, curqpt.x(), curqpt.y());
 	drawBezier(tmp_bezier, currentColor, true);
 	bezier_count++;
       } else {
-	tmp_bezier.setPoint(bezier_count, e1->pos().x(), e1->pos().y());
+	tmp_bezier.setPoint(bezier_count, curqpt.x(), curqpt.y());
 	// add new GraphicObject
 	evt = new XDC_Event(EVT_ADD_GRAPHIC);
 	evt->setPointArray(tmp_bezier);
@@ -445,7 +492,7 @@ void Render2D::mouseReleaseEvent(QMouseEvent *e1) {
       return;
     }
     if ( (mode > 600) && (mode < 699) ) {
-      tmp_pt = new DPoint(e1->pos());
+      tmp_pt = new DPoint(curqpt);
       c->Tool(tmp_pt, mode);
       repaint(false);
       //if (mode == MODE_TOOL_CLEANUPMOL) {
@@ -471,7 +518,9 @@ void Render2D::mouseReleaseEvent(QMouseEvent *e1) {
       bool shiftdown = false;
       if ((e1->state() & ShiftButton) == ShiftButton)
 	shiftdown = true;
-      c->NewSelectRect(QRect(selectOrigin, selectPrev), shiftdown);
+      c->NewSelectRect( QRect( zoomCorrectReverse(selectOrigin), 
+			       zoomCorrectReverse(selectPrev) ), 
+			shiftdown);
       selectionBox = c->selectionBox();
       if (selectionBox.left() < 999)
 	mode = MODE_SELECT_MULTIPLE_SELECTED;
@@ -518,7 +567,7 @@ void Render2D::mouseReleaseEvent(QMouseEvent *e1) {
 	if (endpoint == NULL) {
 	  endpoint = new DPoint;
 	  endpoint->set
-	    (e1->pos());
+	    (curqpt);
 	}
 	// submit this line/bond to ChemData
 	if (startpoint != endpoint) {
@@ -551,8 +600,7 @@ void Render2D::mouseReleaseEvent(QMouseEvent *e1) {
       if (moved) {
 	if (endpoint == NULL) {
 	  endpoint = new DPoint;
-	  endpoint->set
-	    (e1->pos());
+	  endpoint->set(curqpt);
 	}
 	// submit this set of lines/bonds to ChemData
 	double ang, len;
@@ -566,13 +614,13 @@ void Render2D::mouseReleaseEvent(QMouseEvent *e1) {
 	}
 	len = startpoint->distanceTo(endpoint);
 	double blen = preferences.getBond_fixedlength();
-	int n1, nseg = lround(len / blen);
+	int n1, nseg = my_round(len / blen);
 	QPoint spoint, epoint, ipoint1, ipoint2;
 	spoint = startpoint->toQPoint();
 	ipoint1 = spoint;
 	for (n1 = 0; n1 < nseg; n1++) {
-	  ipoint2.setX( lround(ipoint1.x() + cos(alt_ang1) * blen) );
-	  ipoint2.setY( lround(ipoint1.y() + sin(alt_ang1) * blen) );
+	  ipoint2.setX( my_round(ipoint1.x() + cos(alt_ang1) * blen) );
+	  ipoint2.setY( my_round(ipoint1.y() + sin(alt_ang1) * blen) );
 	  //drawLine( ipoint1, ipoint2, 1, currentColor );
 	  evt = new XDC_Event(EVT_ADD_BOND);
 	  if (n1 == 0)
@@ -602,7 +650,7 @@ void Render2D::mouseReleaseEvent(QMouseEvent *e1) {
             if (endpoint == NULL) {
                 endpoint = new DPoint;
                 endpoint->set
-                (e1->pos());
+                (curqpt);
             }
             // submit this line/bond to ChemData
 	    evt = new XDC_Event(EVT_ADD_BOND_DASH);
@@ -627,7 +675,7 @@ void Render2D::mouseReleaseEvent(QMouseEvent *e1) {
             if (endpoint == NULL) {
                 endpoint = new DPoint;
                 endpoint->set
-                (e1->pos());
+                (curqpt);
             }
             // submit this line/bond to ChemData
 	    evt = new XDC_Event(EVT_ADD_BOND_UP);
@@ -651,7 +699,7 @@ void Render2D::mouseReleaseEvent(QMouseEvent *e1) {
             if (endpoint == NULL) {
                 endpoint = new DPoint;
                 endpoint->set
-                (e1->pos());
+                (curqpt);
             }
             // submit this line/bond to ChemData
 	    evt = new XDC_Event(EVT_ADD_BOND_DOWN);
@@ -675,7 +723,7 @@ void Render2D::mouseReleaseEvent(QMouseEvent *e1) {
 	if (endpoint == NULL) {
 	  endpoint = new DPoint;
 	  endpoint->set
-	    (e1->pos());
+	    (curqpt);
 	}
 	// submit this line/bond to ChemData
 	evt = new XDC_Event(EVT_ADD_BOND_WAVY);
@@ -698,7 +746,7 @@ void Render2D::mouseReleaseEvent(QMouseEvent *e1) {
             if (endpoint == NULL) {
                 endpoint = new DPoint;
                 endpoint->set
-                (e1->pos());
+                (curqpt);
             }
             // submit this arrow to ChemData
 	    evt = new XDC_Event(EVT_ADD_ARROW);
@@ -720,7 +768,7 @@ void Render2D::mouseReleaseEvent(QMouseEvent *e1) {
     if ( (mode == MODE_DRAWCURVEARROW_DRAWING) && (!mouse1down) ) {
         endpoint = new DPoint;
         endpoint->set
-        (e1->pos());
+        (curqpt);
 	// submit this arrow to ChemData
 	evt = new XDC_Event(EVT_ADD_CURVEARROW);
 	evt->setStart(startpoint);
@@ -760,7 +808,7 @@ void Render2D::mouseReleaseEvent(QMouseEvent *e1) {
     if ( (mode == MODE_SYMBOL) && (!mouse1down) ) {
         endpoint = new DPoint;
         endpoint->set
-        (e1->pos());
+        (curqpt);
         if (highlightpoint != 0) {
             c->addSymbol(highlightpoint, symbolfile);  // add to existing point
         } else {
@@ -773,14 +821,14 @@ void Render2D::mouseReleaseEvent(QMouseEvent *e1) {
     // MODE_DRAWNEWMAN_*: create Newman projection
     if ( (mode == MODE_DRAWNEWMAN_ANTI) && (!mouse1down) ) {
       endpoint = new DPoint;
-      endpoint->set(e1->pos());
+      endpoint->set(curqpt);
       double blen = preferences.getBond_fixedlength();
       int n1, nn;
       QPoint ipoint1 = endpoint->toQPoint();
       QPoint ipoint2;
       for (n1 = 30; n1 < 331; n1 = n1 + 60) {
-	ipoint2.setX( lround(ipoint1.x() + cos( (double)n1 * M_PI / 180.0) * blen) );
-	ipoint2.setY( lround(ipoint1.y() + sin( (double)n1 * M_PI / 180.0) * blen) );
+	ipoint2.setX( my_round(ipoint1.x() + cos( (double)n1 * M_PI / 180.0) * blen) );
+	ipoint2.setY( my_round(ipoint1.y() + sin( (double)n1 * M_PI / 180.0) * blen) );
 	tmp_pt = new DPoint(ipoint2);
 	evt = new XDC_Event(EVT_ADD_BOND);
 	evt->setStart(endpoint);
@@ -797,14 +845,14 @@ void Render2D::mouseReleaseEvent(QMouseEvent *e1) {
     // MODE_DRAWNEWMAN_*: create Newman projection
     if ( (mode == MODE_DRAWNEWMAN_GAUCHE) && (!mouse1down) ) {
       endpoint = new DPoint;
-      endpoint->set(e1->pos());
+      endpoint->set(curqpt);
       double blen = preferences.getBond_fixedlength();
       int n1, nn;
       QPoint ipoint1 = endpoint->toQPoint();
       QPoint ipoint2;
       for (n1 = 30; n1 < 331; n1 = n1 + 120) {
-	ipoint2.setX( lround(ipoint1.x() + cos( (double)n1 * M_PI / 180.0) * blen) );
-	ipoint2.setY( lround(ipoint1.y() + sin( (double)n1 * M_PI / 180.0) * blen) );
+	ipoint2.setX( my_round(ipoint1.x() + cos( (double)n1 * M_PI / 180.0) * blen) );
+	ipoint2.setY( my_round(ipoint1.y() + sin( (double)n1 * M_PI / 180.0) * blen) );
 	tmp_pt = new DPoint(ipoint2);
 	evt = new XDC_Event(EVT_ADD_BOND);
 	evt->setStart(endpoint);
@@ -814,8 +862,8 @@ void Render2D::mouseReleaseEvent(QMouseEvent *e1) {
 	emit XDCEventSignal(evt);
       }
       for (n1 = 50; n1 < 351; n1 = n1 + 120) {
-	ipoint2.setX( lround(ipoint1.x() + cos( (double)n1 * M_PI / 180.0) * blen) );
-	ipoint2.setY( lround(ipoint1.y() + sin( (double)n1 * M_PI / 180.0) * blen) );
+	ipoint2.setX( my_round(ipoint1.x() + cos( (double)n1 * M_PI / 180.0) * blen) );
+	ipoint2.setY( my_round(ipoint1.y() + sin( (double)n1 * M_PI / 180.0) * blen) );
 	tmp_pt = new DPoint(ipoint2);
 	evt = new XDC_Event(EVT_ADD_BOND);
 	evt->setStart(endpoint);
@@ -833,7 +881,7 @@ void Render2D::mouseReleaseEvent(QMouseEvent *e1) {
     if ( (mode == MODE_RING) && (!mouse1down) ) {
         endpoint = new DPoint;
         endpoint->set
-        (e1->pos());
+        (curqpt);
         // are we smart-placing this ring?
         if ( (smartplace != 0) && (highlightpoint != 0) ) {
             cout << "smart placement!" << endl;
@@ -877,15 +925,15 @@ void Render2D::mouseMoveEvent(QMouseEvent *e1) {
   if ( (mode == MODE_RING) && mouse1down )
     return;
 
-  QPoint curqpt = e1->pos();
+  QPoint curqpt = zoomCorrectReverse( e1->pos() );
   if (preferences.getSnapGrid() != GRID_NONE) {
     curqpt = GridLock(curqpt);
   }
 
-    moved = true;
+  moved = true;
 
-    DPoint tmp_pt(e1->x(), e1->y()); 
-    Molecule *tmp_mol;
+  DPoint tmp_pt(curqpt.x(), curqpt.y()); 
+  Molecule *tmp_mol;
 
     // Tools
     if (mode == MODE_TOOL_CALCMW) {
@@ -945,8 +993,8 @@ void Render2D::mouseMoveEvent(QMouseEvent *e1) {
 	if (prevpos == 0) { 
 	  prevpos = new DPoint;
 	}
-        prevpos->x = e1->x();
-        prevpos->y = e1->y();
+        prevpos->x = curqpt.x();
+        prevpos->y = curqpt.y();
         return;
     }
     // MODE_SELECT: call special function to handle select events
@@ -955,8 +1003,8 @@ void Render2D::mouseMoveEvent(QMouseEvent *e1) {
 	if (prevpos == 0) { 
 	  prevpos = new DPoint;
 	}
-	prevpos->x = e1->x();
-	prevpos->y = e1->y();
+	prevpos->x = curqpt.x();
+	prevpos->y = curqpt.y();
         return;
     }
 
@@ -972,8 +1020,8 @@ void Render2D::mouseMoveEvent(QMouseEvent *e1) {
     // Create DPoint of current pointer position
     DPoint *e = new DPoint;
     DPoint *np = 0;
-    e->x = e1->x();
-    e->y = e1->y();
+    e->x = curqpt.x();
+    e->y = curqpt.y();
     double dist, distobj;
     // Get DPoint of nearest point
     np = c->FindNearestPoint(e, dist);
@@ -1208,8 +1256,8 @@ void Render2D::mouseMoveEvent(QMouseEvent *e1) {
             endpoint = np;
         } else {
             endpoint = new DPoint;
-            endpoint->x = e1->x();
-            endpoint->y = e1->y();
+            endpoint->x = curqpt.x();
+            endpoint->y = curqpt.y();
             highlightpoint = 0;  // stop highlighting
             if (preferences.getBond_fixed()) { // fix endpoint if fixed set
                 CorrectEndpoint_bond();
@@ -1240,8 +1288,8 @@ void Render2D::mouseMoveEvent(QMouseEvent *e1) {
             endpoint = np;
         } else {
             endpoint = new DPoint;
-            endpoint->x = e1->x();
-            endpoint->y = e1->y();
+            endpoint->x = curqpt.x();
+            endpoint->y = curqpt.y();
             highlightpoint = 0;  // stop highlighting
         }
         ang = Drawable::getAngle(startpoint, endpoint);
@@ -1253,15 +1301,15 @@ void Render2D::mouseMoveEvent(QMouseEvent *e1) {
 	}
         len = startpoint->distanceTo(endpoint);
         double blen = preferences.getBond_fixedlength();
-	int n1, nseg = lround(len / blen);
+	int n1, nseg = my_round(len / blen);
 	slen.setNum(nseg);
         emit SignalSetStatusBar( tr("Draw aliphatic chain - Length = ") + slen + tr(" bonds") );
 	QPoint spoint, epoint, ipoint1, ipoint2;
 	spoint = startpoint->toQPoint();
 	ipoint1 = spoint;
 	for (n1 = 0; n1 < nseg; n1++) {
-	  ipoint2.setX( lround(ipoint1.x() + cos(alt_ang1) * blen) );
-	  ipoint2.setY( lround(ipoint1.y() + sin(alt_ang1) * blen) );
+	  ipoint2.setX( my_round(ipoint1.x() + cos(alt_ang1) * blen) );
+	  ipoint2.setY( my_round(ipoint1.y() + sin(alt_ang1) * blen) );
 	  drawLine( ipoint1, ipoint2, 1, currentColor );
 	  alt_swap = alt_ang1; alt_ang1 = alt_ang2; alt_ang2 = alt_swap;
 	  ipoint1 = ipoint2;
@@ -1279,8 +1327,8 @@ void Render2D::mouseMoveEvent(QMouseEvent *e1) {
             endpoint = np;
         } else {
             endpoint = new DPoint;
-            endpoint->x = e1->x();
-            endpoint->y = e1->y();
+            endpoint->x = curqpt.x();
+            endpoint->y = curqpt.y();
             highlightpoint = 0;  // stop highlighting
             if (preferences.getBond_fixed()) { // fix endpoint if fixed set
                 CorrectEndpoint_bond();
@@ -1306,8 +1354,8 @@ void Render2D::mouseMoveEvent(QMouseEvent *e1) {
             endpoint = np;
         } else {
             endpoint = new DPoint;
-            endpoint->x = e1->x();
-            endpoint->y = e1->y();
+            endpoint->x = curqpt.x();
+            endpoint->y = curqpt.y();
             highlightpoint = 0;  // stop highlighting
             if (preferences.getBond_fixed()) { // fix endpoint if fixed set
                 CorrectEndpoint_bond();
@@ -1332,8 +1380,8 @@ void Render2D::mouseMoveEvent(QMouseEvent *e1) {
             endpoint = np;
         } else {
             endpoint = new DPoint;
-            endpoint->x = e1->x();
-            endpoint->y = e1->y();
+            endpoint->x = curqpt.x();
+            endpoint->y = curqpt.y();
             highlightpoint = 0;  // stop highlighting
             if (preferences.getBond_fixed()) { // fix endpoint if fixed set
                 CorrectEndpoint_bond();
@@ -1358,8 +1406,8 @@ void Render2D::mouseMoveEvent(QMouseEvent *e1) {
 	endpoint = np;
       } else {
 	endpoint = new DPoint;
-	endpoint->x = e1->x();
-	endpoint->y = e1->y();
+	endpoint->x = curqpt.x();
+	endpoint->y = curqpt.y();
 	highlightpoint = 0;  // stop highlighting
 	if (preferences.getBond_fixed()) { // fix endpoint if fixed set
 	  CorrectEndpoint_bond();
@@ -1378,8 +1426,8 @@ void Render2D::mouseMoveEvent(QMouseEvent *e1) {
     // MODE_DRAWARROW_DRAWING: draw temporary arrow
     if ( (mode == MODE_DRAWARROW_DRAWING) && mouse1down ) {
         endpoint = new DPoint;
-        endpoint->x = e1->x();
-        endpoint->y = e1->y();
+        endpoint->x = curqpt.x();
+        endpoint->y = curqpt.y();
         if (preferences.getArrow_fixed()) { // fix endpoint if fixed set
             CorrectEndpoint_arrow();
         }
@@ -1392,8 +1440,8 @@ void Render2D::mouseMoveEvent(QMouseEvent *e1) {
     // MODE_DRAWCURVEARROW_DRAWING: draw temporary curve arrow
     if ( (mode == MODE_DRAWCURVEARROW_DRAWING) && mouse1down ) {
         endpoint = new DPoint;
-        endpoint->x = e1->x();
-        endpoint->y = e1->y();
+        endpoint->x = curqpt.x();
+        endpoint->y = curqpt.y();
         // should not draw curve arrows fixed, even if selected
         //if (fixed) { // fix endpoint if fixed set
         //  CorrectEndpoint();
@@ -1404,16 +1452,34 @@ void Render2D::mouseMoveEvent(QMouseEvent *e1) {
         return;
     }
 
-    // MODE_DRAWBRACKET_DRAWING: draw temporary bracket
-    if ( (mode == MODE_DRAWBRACKET_DRAWING) && mouse1down ) {
-        endpoint = new DPoint;
-        endpoint->x = e1->x();
-        endpoint->y = e1->y();
-        drawBracket( startpoint->toQPoint(), endpoint->toQPoint(), currentColor,
-                     bracket_type );
-        directdraw = false;
-        return;
+  // MODE_DRAWBRACKET_DRAWING: draw temporary bracket
+  if ( (mode == MODE_DRAWBRACKET_DRAWING) && mouse1down ) {
+    endpoint = new DPoint;
+    endpoint->x = curqpt.x();
+    endpoint->y = curqpt.y();
+    // adjust position for square and circle "brackets"
+    if ( (bracket_type == BRACKET_CLOSEDSQUARE) || 
+	 (bracket_type == BRACKET_CIRCLE) ) {
+      double bdx = endpoint->x - startpoint->x;
+      double bdy = endpoint->y - startpoint->y;
+      double mgn = fabs(bdx / bdy);
+      if (bdx > bdy) {
+	bdy *= mgn;
+	endpoint->y = startpoint->y + bdy;
+      }
+      if (bdx < bdy) {
+	bdx /= mgn;
+	endpoint->x = startpoint->x + bdx;
+      }
+      bdx = endpoint->x - startpoint->x;
+      bdy = endpoint->y - startpoint->y;
+      std::cout << "after:" << bdx << "," << bdy << std::endl;
     }
+    drawBracket( startpoint->toQPoint(), endpoint->toQPoint(), currentColor,
+		 bracket_type );
+    directdraw = false;
+    return;
+  }
 }
 
 // handle resize event
@@ -1429,7 +1495,7 @@ void Render2D::paintEvent(QPaintEvent *) {
     // draw grid as needed
     int i1, cl1;
     if (preferences.getDrawGrid() == GRID_SQUARE) {
-      i1 = (int)preferences.getGridSpacing();
+      i1 = my_round( (double)preferences.getGridSpacing() * zoomFactor );
       QPainter p;
       if (directdraw) 
 	p.begin(this);
@@ -1447,7 +1513,7 @@ void Render2D::paintEvent(QPaintEvent *) {
     }
     if (preferences.getDrawGrid() == GRID_HEX) {
       bool hexoffset = true;
-      i1 = (int)preferences.getGridSpacing();
+      i1 = my_round( (double)preferences.getGridSpacing() * zoomFactor );
       double hexhoriz = (double)i1 / 2.0;
       double hexgap = 2.0 * hexhoriz + (double)i1;
       double hexelevation = hexhoriz * 1.73205;
@@ -1478,10 +1544,10 @@ void Render2D::paintEvent(QPaintEvent *) {
     c->drawAll();
     // local/temporary draw operations
     if (highlightpoint != 0) {
-        drawBox(QPoint( lround(highlightpoint->x - 2.0), 
-			lround(highlightpoint->y - 2.0) ),
-                QPoint( lround(highlightpoint->x + 2.0), 
-			lround(highlightpoint->y + 2.0) ),
+        drawBox(QPoint( my_round(highlightpoint->x - 2.0), 
+			my_round(highlightpoint->y - 2.0) ),
+                QPoint( my_round(highlightpoint->x + 2.0), 
+			my_round(highlightpoint->y + 2.0) ),
                 QColor(0,0,0));
     }
     if ( (mode == MODE_TEXT) && (localtext != 0) )
@@ -1503,35 +1569,53 @@ void Render2D::paintEvent(QPaintEvent *) {
     // if multiple selection, draw rotate and resize handles
     if ( (mode > 120) && (mode < 129) ) {
         // draw selection box
-        drawBox(selectionBox.topLeft(), selectionBox.bottomRight(),
+        drawBox( (selectionBox.topLeft() ), 
+		 (selectionBox.bottomRight() ),
                 QColor(0,0,0));
         // draw rotate handle
         rotateHandle = selectionBox.topRight();
-        drawFillBox( QPoint(rotateHandle.x() - 5, rotateHandle.y()),
-                     QPoint(rotateHandle.x(), rotateHandle.y() + 5),
+        drawFillBox( ( QPoint(rotateHandle.x() - 5, rotateHandle.y()) ),
+                     ( QPoint(rotateHandle.x(), rotateHandle.y() + 5) ),
                      QColor(0,0,0) );
         // draw resize handle
         resizeHandle = selectionBox.bottomRight();
-        drawFillBox( QPoint(resizeHandle.x() - 5, resizeHandle.y() - 5),
-                     resizeHandle,
+        drawFillBox( ( QPoint(resizeHandle.x() - 5, resizeHandle.y() - 5) ),
+                     ( resizeHandle ),
                      QColor(0,0,0) );
     }
     if (mode == 91) {
         // draw selection box
-        drawBox(selectionBox.topLeft(), selectionBox.bottomRight(),
+        drawBox( ( selectionBox.topLeft() ), 
+		 ( selectionBox.bottomRight() ),
                 QColor(0,0,0));
         // draw rotate handle
         rotateHandle = selectionBox.topRight();
-        drawFillBox( QPoint(rotateHandle.x() - 5, rotateHandle.y()),
-                     QPoint(rotateHandle.x(), rotateHandle.y() + 5),
+        drawFillBox( ( QPoint(rotateHandle.x() - 5, rotateHandle.y()) ),
+                     ( QPoint(rotateHandle.x(), rotateHandle.y() + 5) ),
                      QColor(0,0,0) );
         // draw resize handle
         resizeHandle = selectionBox.bottomRight();
-        drawFillBox( QPoint(resizeHandle.x() - 5, resizeHandle.y() - 5),
-                     resizeHandle,
+        drawFillBox( ( QPoint(resizeHandle.x() - 5, resizeHandle.y() - 5) ),
+                     ( resizeHandle ),
                      QColor(0,0,0) );
     }
     // now bitBlt buffer onto widget
     bitBlt(this, 0, 0, &dbuffer);
     finishedPainting = true;
 }
+
+void Render2D::zoomEvent() {
+  // read zoom factor from preferences and act accordingly
+  double ozf = zoomFactor;
+  zoomFactor = (double)preferences.getZoom() / 100.0;
+
+  // scale canvas
+  double sf = zoomFactor / ozf;
+  renderWidth = my_round( (double)renderWidth * sf );
+  renderHeight = my_round( (double)renderHeight * sf );
+  dbuffer.resize(renderWidth, renderHeight);
+  resize(renderWidth, renderHeight);
+
+  // redraw
+  repaint(false);
+}
