@@ -207,7 +207,14 @@ void Render2D::DrawText_mouseMoveEvent(QMouseEvent *e1) {
 
 // Handle keypress event here, since it only really applies to text
 void Render2D::keyPressEvent(QKeyEvent *k) {
-  if (mode != MODE_TEXT) return;
+  if (mode != MODE_TEXT) {
+    if (k->key() == Key_Escape) {
+      setMode_Select();
+      return;
+    } else {
+      return;
+    }
+  }
 
   // discard delete key (to avoid random behavior)
   if (k->key() == Key_Delete) {
